Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(290)

Unified Diff: pkg/analysis_server/lib/src/server/driver.dart

Issue 2543713002: Add a new Analysis Server option '--new-analysis-driver-log'. (Closed)
Patch Set: Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/analysis_server/lib/src/analysis_server.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analysis_server/lib/src/server/driver.dart
diff --git a/pkg/analysis_server/lib/src/server/driver.dart b/pkg/analysis_server/lib/src/server/driver.dart
index f813e78a44d248847d0940c053b32fc5f22c41e2..2f180ee61aeef22b511de648a6009737ba0c12f4 100644
--- a/pkg/analysis_server/lib/src/server/driver.dart
+++ b/pkg/analysis_server/lib/src/server/driver.dart
@@ -243,7 +243,7 @@ class Driver implements ServerStarter {
"incremental-resolution-validation";
/**
* The name of the option used to enable using pub summary manager.
*/
static const String ENABLE_NEW_ANALYSIS_DRIVER = 'enable-new-analysis-driver';
@@ -276,6 +276,11 @@ class Driver implements ServerStarter {
static const String INTERNAL_PRINT_TO_CONSOLE = "internal-print-to-console";
/**
+ * The name of the option used to describe the new analysis driver logger.
+ */
+ static const String NEW_ANALYSIS_DRIVER_LOG = 'new-analysis-driver-log';
+
+ /**
* The name of the flag used to disable error notifications.
*/
static const String NO_ERROR_NOTIFICATION = "no-error-notification";
@@ -399,6 +404,8 @@ class Driver implements ServerStarter {
analysisServerOptions.useAnalysisHighlight2 =
results[USE_ANALISYS_HIGHLIGHT2];
analysisServerOptions.fileReadMode = results[FILE_READ_MODE];
+ analysisServerOptions.newAnalysisDriverLog =
+ results[NEW_ANALYSIS_DRIVER_LOG];
_initIncrementalLogger(results[INCREMENTAL_RESOLUTION_LOG]);
@@ -559,6 +566,8 @@ class Driver implements ServerStarter {
help: "enable sending `print` output to the console",
defaultsTo: false,
negatable: false);
+ parser.addOption(NEW_ANALYSIS_DRIVER_LOG,
+ help: "set a destination for the new analysis driver's log");
parser.addOption(PORT_OPTION,
help: "the http diagnostic port on which the server provides"
" status and performance information");
@@ -243,7 +243,7 @@ class Driver implements ServerStarter {
"incremental-resolution-validation";
/**
- * The name of the option used to enable using pub summary manager.
+ * The name of the option used to enable using the new analysis driver.
*/
static const String ENABLE_NEW_ANALYSIS_DRIVER = 'enable-new-analysis-driver';
« no previous file with comments | « pkg/analysis_server/lib/src/analysis_server.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698